==> vue-hooks-plus-1.3.1.tgz: package/lib/useFetchs/index.js <==
"use strict";
const vue = require("vue");
const useRequest = require("../useRequest/index");
const _interopDefaultLegacy = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const useRequest__default = /* @__PURE__ */ _interopDefaultLegacy(useRequest);
const DEFAULT_KEY = "VUE_HOOKS_PLUS_USE_REQUEST_DEFAULT_KEY";
function useFetchs(service, options, self) {
  const fetchKeyPersist = vue.ref(self == null ? void 0 : self.fetchKey);
  const fetchs = vue.ref({});
  const newFetchs = vue.ref({});
  const getFetchs = (fetchs_) => {
    newFetchs.value = fetchs_;
  };
  const fetchRun = (...args) => {
    var _a, _b;
    const newstFetchKey = vue.ref();
    const cacheKey = (_b = (_a = fetchKeyPersist.value) == null ? void 0 : _a.call(fetchKeyPersist, ...args)) != null ? _b : DEFAULT_KEY;
    newstFetchKey.value = cacheKey;
    const { data, run, params, loading } = useRequest__default.default(service, {
      ...options,
      cacheKey,
      manual: true
    });
    fetchs.value[cacheKey] = { key: cacheKey, data, params, loading };
    getFetchs(fetchs.value);
    run(...args);
    vue.watch([data, params, loading, newstFetchKey], (curr) => {
      const [
        newData = void 0,
        newParams = void 0,
        newLoading = false,
        key = DEFAULT_KEY
      ] = curr;
      fetchs.value[key] = {
        key,
        data: newData,
        params: newParams,
        loading: newLoading
      };
      getFetchs(fetchs.value);
    });
  };
  return {
    fetchs: newFetchs,
    fetchRun
  };
}
module.exports = useFetchs;

==> vue-hooks-plus-1.3.3.tgz: package/lib/useFetchs/index.js <==
"use strict";
const vue = require("vue");
const useRequest = require("../useRequest/index");
const _interopDefaultLegacy = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const useRequest__default = /* @__PURE__ */ _interopDefaultLegacy(useRequest);
const DEFAULT_KEY = "VUE_HOOKS_PLUS_USE_REQUEST_DEFAULT_KEY";
function useFetchs(service, options, self) {
  const fetchKeyPersist = vue.ref(self == null ? void 0 : self.fetchKey);
  const fetchs = vue.ref({});
  const newFetchs = vue.ref({});
  const getFetchs = (fetchs_) => {
    newFetchs.value = fetchs_;
  };
  const fetchRun = (...args) => {
    var _a, _b;
    const newstFetchKey = vue.ref();
    const cacheKey = (_b = (_a = fetchKeyPersist.value) == null ? void 0 : _a.call(fetchKeyPersist, ...args)) != null ? _b : DEFAULT_KEY;
    newstFetchKey.value = cacheKey;
    const { data, run, params, loading } = useRequest__default.default(service, {
      ...options,
      cacheKey,
      manual: true
    });
    vue.watchEffect(() => {
      fetchs.value[cacheKey] = {
        key: cacheKey,
        data: data == null ? void 0 : data.value,
        params: params.value,
        loading: loading.value
      };
      getFetchs(fetchs.value);
    });
    run(...args);
    vue.watch([data, params, loading, newstFetchKey], (curr) => {
      const [
        newData = void 0,
        newParams = void 0,
        newLoading = false,
        key = DEFAULT_KEY
      ] = curr;
      fetchs.value[key] = {
        key,
        data: newData,
        params: newParams,
        loading: newLoading
      };
      getFetchs(fetchs.value);
    });
  };
  return {
    fetchs: newFetchs,
    fetchRun
  };
}
module.exports = useFetchs;
